@@ -1,6 +1,6 @@
 //
 //  CocoaGroupBox.h
-//  
+//
 //
 //  Created by Samuel Strupp on 10.08.10.
 //
@@ -8,9 +8,10 @@
 #import <Cocoa/Cocoa.h>
 #import "CocoaGwenGUIProtocol.h"
 
-@interface CocoaGroupBox : NSBox <CocoaGwenGUIProtocol> {
-	BOOL fillX;
-	BOOL fillY;
+@interface CocoaGroupBox : NSBox <CocoaGwenGUIProtocol>
+{
+  BOOL fillX;
+  BOOL fillY;
 }
 
 @property BOOL fillX;
