@@ -14,15 +14,16 @@
 static GWENHYWFAR_CB
 int Gtk2Gui_WVLayout_SetIntProperty(GWEN_WIDGET *w,
                                     GWEN_DIALOG_PROPERTY prop,
-                                    int index,
+                                    GWEN_UNUSED int index,
                                     int value,
-                                    int doSignal) {
+                                    GWEN_UNUSED int doSignal)
+{
   GtkWidget *g;
 
   g=GTK_WIDGET(GWEN_Widget_GetImplData(w, GTK2_DIALOG_WIDGET_REAL));
   assert(g);
 
-  switch(prop) {
+  switch (prop) {
   case GWEN_DialogProperty_Enabled:
     gtk_widget_set_sensitive(GTK_WIDGET(g), (value==0)?FALSE:TRUE);
     return 0;
@@ -47,14 +48,15 @@ int Gtk2Gui_WVLayout_SetIntProperty(GWEN_WIDGET *w,
 static GWENHYWFAR_CB
 int Gtk2Gui_WVLayout_GetIntProperty(GWEN_WIDGET *w,
                                     GWEN_DIALOG_PROPERTY prop,
-                                    int index,
-                                    int defaultValue) {
+                                    GWEN_UNUSED int index,
+                                    int defaultValue)
+{
   GtkWidget *g;
 
   g=GTK_WIDGET(GWEN_Widget_GetImplData(w, GTK2_DIALOG_WIDGET_REAL));
   assert(g);
 
-  switch(prop) {
+  switch (prop) {
   case GWEN_DialogProperty_Enabled:
     return (gtk_widget_get_sensitive(GTK_WIDGET(g))==TRUE)?1:0;
 
@@ -76,10 +78,11 @@ int Gtk2Gui_WVLayout_GetIntProperty(GWEN_WIDGET *w,
 
 static GWENHYWFAR_CB
 int Gtk2Gui_WVLayout_SetCharProperty(GWEN_WIDGET *w,
-                                     GWEN_DIALOG_PROPERTY prop,
-                                     int index,
-                                     const char *value,
-                                     int doSignal) {
+                                     GWEN_UNUSED GWEN_DIALOG_PROPERTY prop,
+                                     GWEN_UNUSED int index,
+                                     GWEN_UNUSED const char *value,
+                                     GWEN_UNUSED int doSignal)
+{
   GtkWidget *g;
 
   g=GTK_WIDGET(GWEN_Widget_GetImplData(w, GTK2_DIALOG_WIDGET_REAL));
@@ -94,10 +97,11 @@ int Gtk2Gui_WVLayout_SetCharProperty(GWEN_WIDGET *w,
 
 
 static GWENHYWFAR_CB
-const char* Gtk2Gui_WVLayout_GetCharProperty(GWEN_WIDGET *w,
-    GWEN_DIALOG_PROPERTY prop,
-    int index,
-    const char *defaultValue) {
+const char *Gtk2Gui_WVLayout_GetCharProperty(GWEN_WIDGET *w,
+                                             GWEN_UNUSED GWEN_DIALOG_PROPERTY prop,
+                                             GWEN_UNUSED int index,
+                                             const char *defaultValue)
+{
   GtkWidget *g;
 
   g=GTK_WIDGET(GWEN_Widget_GetImplData(w, GTK2_DIALOG_WIDGET_REAL));
@@ -112,7 +116,8 @@ const char* Gtk2Gui_WVLayout_GetCharProperty(GWEN_WIDGET *w,
 
 
 static GWENHYWFAR_CB
-int Gtk2Gui_WVLayout_AddChildGuiWidget(GWEN_WIDGET *w, GWEN_WIDGET *wChild) {
+int Gtk2Gui_WVLayout_AddChildGuiWidget(GWEN_WIDGET *w, GWEN_WIDGET *wChild)
+{
   GtkWidget *g;
   GtkWidget *gChild;
   uint32_t cflags;
@@ -135,7 +140,8 @@ int Gtk2Gui_WVLayout_AddChildGuiWidget(GWEN_WIDGET *w, GWEN_WIDGET *wChild) {
 
 
 
-int Gtk2Gui_WVLayout_Setup(GWEN_WIDGET *w) {
+int Gtk2Gui_WVLayout_Setup(GWEN_WIDGET *w)
+{
   GtkWidget *g;
   uint32_t flags;
   GWEN_WIDGET *wParent;
@@ -145,8 +151,8 @@ int Gtk2Gui_WVLayout_Setup(GWEN_WIDGET *w) {
 
   g=gtk_vbox_new((flags & GWEN_WIDGET_FLAGS_EQUAL_HEIGHT)?TRUE:FALSE,
                  GTK2_GUI_DIALOG_DEFAULT_BOX_SPACING);
-  GWEN_Widget_SetImplData(w, GTK2_DIALOG_WIDGET_REAL, (void*) g);
-  GWEN_Widget_SetImplData(w, GTK2_DIALOG_WIDGET_CONTENT, (void*) g);
+  GWEN_Widget_SetImplData(w, GTK2_DIALOG_WIDGET_REAL, (void *) g);
+  GWEN_Widget_SetImplData(w, GTK2_DIALOG_WIDGET_CONTENT, (void *) g);
 
   GWEN_Widget_SetSetIntPropertyFn(w, Gtk2Gui_WVLayout_SetIntProperty);
   GWEN_Widget_SetGetIntPropertyFn(w, Gtk2Gui_WVLayout_GetIntProperty);
