@@ -14,9 +14,10 @@
 static GWENHYWFAR_CB
 int Gtk3Gui_WTextBrowser_SetIntProperty(GWEN_WIDGET *w,
                                         GWEN_DIALOG_PROPERTY prop,
-                                        int index,
+                                        GWEN_UNUSED int index,
                                         int value,
-                                        int doSignal) {
+                                        GWEN_UNUSED int doSignal)
+{
   GtkWidget *g;  /* text view */
   GtkWidget *gs; /* scrollable window */
 
@@ -25,7 +26,7 @@ int Gtk3Gui_WTextBrowser_SetIntProperty(GWEN_WIDGET *w,
   gs=GTK_WIDGET(GWEN_Widget_GetImplData(w, GTK3_DIALOG_WIDGET_REAL));
   assert(gs);
 
-  switch(prop) {
+  switch (prop) {
   case GWEN_DialogProperty_Enabled:
     gtk_widget_set_sensitive(GTK_WIDGET(gs), (value==0)?FALSE:TRUE);
     return 0;
@@ -55,8 +56,9 @@ int Gtk3Gui_WTextBrowser_SetIntProperty(GWEN_WIDGET *w,
 static GWENHYWFAR_CB
 int Gtk3Gui_WTextBrowser_GetIntProperty(GWEN_WIDGET *w,
                                         GWEN_DIALOG_PROPERTY prop,
-                                        int index,
-                                        int defaultValue) {
+                                        GWEN_UNUSED int index,
+                                        int defaultValue)
+{
   GtkWidget *g;  /* text view */
   GtkWidget *gs; /* scrollable window */
 
@@ -68,7 +70,7 @@ int Gtk3Gui_WTextBrowser_GetIntProperty(GWEN_WIDGET *w,
   g=GTK_WIDGET(GWEN_Widget_GetImplData(w, GTK3_DIALOG_WIDGET_CONTENT));
   assert(g);
 
-  switch(prop) {
+  switch (prop) {
   case GWEN_DialogProperty_Enabled:
     return (gtk_widget_get_sensitive(GTK_WIDGET(gs))==TRUE)?1:0;
 
@@ -95,10 +97,11 @@ int Gtk3Gui_WTextBrowser_GetIntProperty(GWEN_WIDGET *w,
 
 static GWENHYWFAR_CB
 int Gtk3Gui_WTextBrowser_SetCharProperty(GWEN_WIDGET *w,
-    GWEN_DIALOG_PROPERTY prop,
-    int index,
-    const char *value,
-    int doSignal) {
+                                         GWEN_DIALOG_PROPERTY prop,
+                                         GWEN_UNUSED int index,
+                                         const char *value,
+                                         GWEN_UNUSED int doSignal)
+{
   GtkWidget *g;  /* text view */
   GtkWidget *gs; /* scrollable window */
   GWEN_BUFFER *tbuf;
@@ -112,7 +115,7 @@ int Gtk3Gui_WTextBrowser_SetCharProperty(GWEN_WIDGET *w,
   if (value && *value)
     Gtk3Gui_GetRawText(value, tbuf);
 
-  switch(prop) {
+  switch (prop) {
   case GWEN_DialogProperty_Value: {
     GtkTextBuffer *tb;
     GtkAdjustment *va;
@@ -143,10 +146,11 @@ int Gtk3Gui_WTextBrowser_SetCharProperty(GWEN_WIDGET *w,
 
 
 static GWENHYWFAR_CB
-const char* Gtk3Gui_WTextBrowser_GetCharProperty(GWEN_WIDGET *w,
-    GWEN_DIALOG_PROPERTY prop,
-    int index,
-    const char *defaultValue) {
+const char *Gtk3Gui_WTextBrowser_GetCharProperty(GWEN_WIDGET *w,
+                                                 GWEN_DIALOG_PROPERTY prop,
+                                                 GWEN_UNUSED int index,
+                                                 const char *defaultValue)
+{
   GtkWidget *g;  /* text view */
   GtkWidget *gs; /* scrollable window */
 
@@ -155,7 +159,7 @@ const char* Gtk3Gui_WTextBrowser_GetCharProperty(GWEN_WIDGET *w,
   gs=GTK_WIDGET(GWEN_Widget_GetImplData(w, GTK3_DIALOG_WIDGET_REAL));
   assert(gs);
 
-  switch(prop) {
+  switch (prop) {
   case GWEN_DialogProperty_Value: {
     GtkTextBuffer *tb;
     GtkTextIter startIter;
@@ -189,20 +193,20 @@ const char* Gtk3Gui_WTextBrowser_GetCharProperty(GWEN_WIDGET *w,
 
 
 
-int Gtk3Gui_WTextBrowser_Setup(GWEN_WIDGET *w) {
+int Gtk3Gui_WTextBrowser_Setup(GWEN_WIDGET *w)
+{
   GtkWidget *gs;
   GtkWidget *g;
   const char *s;
-  uint32_t flags;
   GWEN_WIDGET *wParent;
 
-  flags=GWEN_Widget_GetFlags(w);
   wParent=GWEN_Widget_Tree_GetParent(w);
   s=GWEN_Widget_GetText(w, 0);
 
   /* create widget */
   gs=gtk_scrolled_window_new(NULL, NULL);
   g=gtk_text_view_new();
+  gtk_container_add(GTK_CONTAINER(gs), GTK_WIDGET(g));
 
   if (s && *s) {
     GWEN_BUFFER *tbuf;
@@ -213,8 +217,8 @@ int Gtk3Gui_WTextBrowser_Setup(GWEN_WIDGET *w) {
     GWEN_Buffer_free(tbuf);
   }
 
-  GWEN_Widget_SetImplData(w, GTK3_DIALOG_WIDGET_REAL, (void*) gs);
-  GWEN_Widget_SetImplData(w, GTK3_DIALOG_WIDGET_CONTENT, (void*) g);
+  GWEN_Widget_SetImplData(w, GTK3_DIALOG_WIDGET_REAL, (void *) gs);
+  GWEN_Widget_SetImplData(w, GTK3_DIALOG_WIDGET_CONTENT, (void *) g);
 
   GWEN_Widget_SetSetIntPropertyFn(w, Gtk3Gui_WTextBrowser_SetIntProperty);
   GWEN_Widget_SetGetIntPropertyFn(w, Gtk3Gui_WTextBrowser_GetIntProperty);
