@@ -46,15 +46,18 @@ GWEN_INHERIT(GWEN_CONFIGMGR, GWEN_CONFIGMGR_DIR)
 
 
 
-GWEN_CONFIGMGR *GWEN_ConfigMgrDir_Factory(GWEN_UNUSED GWEN_PLUGIN *pl, const char *url) {
+GWEN_CONFIGMGR *GWEN_ConfigMgrDir_Factory(GWEN_UNUSED GWEN_PLUGIN *pl, const char *url)
+{
   GWEN_CONFIGMGR *cfg;
 
   cfg=GWEN_ConfigMgrDir_new(url);
   GWEN_ConfigMgr_SetGetGroupFn(cfg, GWEN_ConfigMgrDir_GetGroup);
   GWEN_ConfigMgr_SetSetGroupFn(cfg, GWEN_ConfigMgrDir_SetGroup);
+  GWEN_ConfigMgr_SetHasGroupFn(cfg, GWEN_ConfigMgrDir_HasGroup);
   GWEN_ConfigMgr_SetLockGroupFn(cfg, GWEN_ConfigMgrDir_LockGroup);
   GWEN_ConfigMgr_SetUnlockGroupFn(cfg, GWEN_ConfigMgrDir_UnlockGroup);
   GWEN_ConfigMgr_SetGetUniqueIdFn(cfg, GWEN_ConfigMgrDir_GetUniqueId);
+  GWEN_ConfigMgr_SetMkUniqueIdFromIdFn(cfg, GWEN_ConfigMgrDir_MkUniqueIdFromId);
   GWEN_ConfigMgr_SetDeleteGroupFn(cfg, GWEN_ConfigMgrDir_DeleteGroup);
   GWEN_ConfigMgr_SetListGroupsFn(cfg, GWEN_ConfigMgrDir_ListGroups);
   GWEN_ConfigMgr_SetListSubGroupsFn(cfg, GWEN_ConfigMgrDir_ListSubGroups);
@@ -65,8 +68,9 @@ GWEN_CONFIGMGR *GWEN_ConfigMgrDir_Factory(GWEN_UNUSED GWEN_PLUGIN *pl, const cha
 
 
 GWEN_PLUGIN *configmgr_dir_factory(GWEN_PLUGIN_MANAGER *pm,
-				   const char *modName,
-				   const char *fileName) {
+                                   const char *modName,
+                                   const char *fileName)
+{
   GWEN_PLUGIN *pl;
 
   pl=GWEN_ConfigMgr_Plugin_new(pm, modName, fileName);
@@ -80,7 +84,8 @@ GWEN_PLUGIN *configmgr_dir_factory(GWEN_PLUGIN_MANAGER *pm,
 
 
 
-GWEN_CONFIGMGR *GWEN_ConfigMgrDir_new(const char *url) {
+GWEN_CONFIGMGR *GWEN_ConfigMgrDir_new(const char *url)
+{
   GWEN_CONFIGMGR *cfg;
   GWEN_CONFIGMGR_DIR *xcfg;
   GWEN_URL *gurl;
@@ -103,11 +108,11 @@ GWEN_CONFIGMGR *GWEN_ConfigMgrDir_new(const char *url) {
     s=GWEN_Url_GetPath(gurl);
     if (s) {
       /* Does this begin with a slash? If not, we add one, but only if
-	 this isn't a drive letter (for windows!) */
+      this isn't a drive letter (for windows!) */
       if (*s!='/' && *s!='\\'
-	  && !(isalpha(s[0]) && s[1] == ':'
-	       && (s[2] == '/' || s[2] == '\\'))) {
-	GWEN_Buffer_AppendString(nbuf, GWEN_DIR_SEPARATOR_S);
+          && !(isalpha(s[0]) && s[1] == ':'
+               && (s[2] == '/' || s[2] == '\\'))) {
+        GWEN_Buffer_AppendString(nbuf, GWEN_DIR_SEPARATOR_S);
       }
       GWEN_Buffer_AppendString(nbuf, s);
     }
@@ -126,22 +131,23 @@ GWEN_CONFIGMGR *GWEN_ConfigMgrDir_new(const char *url) {
 
 
 
-GWENHYWFAR_CB void GWEN_ConfigMgrDir_FreeData(GWEN_UNUSED void *bp, void *p) {
+GWENHYWFAR_CB void GWEN_ConfigMgrDir_FreeData(GWEN_UNUSED void *bp, void *p)
+{
   GWEN_CONFIGMGR_DIR *xcfg;
 
-  xcfg=(GWEN_CONFIGMGR_DIR*) p;
+  xcfg=(GWEN_CONFIGMGR_DIR *) p;
 
   if (GWEN_FSLock_List_GetCount(xcfg->fileLocks)) {
     GWEN_FSLOCK *lck;
 
     DBG_WARN(GWEN_LOGDOMAIN, "Some groups are still locked, unlocking");
     lck=GWEN_FSLock_List_First(xcfg->fileLocks);
-    while(lck) {
+    while (lck) {
       GWEN_FSLOCK_RESULT res;
 
       res=GWEN_FSLock_Unlock(lck);
       if (res!=GWEN_FSLock_ResultOk) {
-	DBG_INFO(GWEN_LOGDOMAIN, "Unable to unlock file [%s]: %d",
+        DBG_INFO(GWEN_LOGDOMAIN, "Unable to unlock file [%s]: %d",
                  GWEN_FSLock_GetName(lck), res);
       }
       lck=GWEN_FSLock_List_Next(lck);
@@ -156,9 +162,9 @@ GWENHYWFAR_CB void GWEN_ConfigMgrDir_FreeData(GWEN_UNUSED void *bp, void *p) {
 
 
 int GWEN_ConfigMgrDir__GetUniqueId(GWEN_CONFIGMGR *cfg,
-				   const char *groupName,
-				   uint32_t *pUniqueId,
-				   uint32_t guiid){
+                                   const char *groupName,
+                                   uint32_t *pUniqueId)
+{
   GWEN_CONFIGMGR_DIR *xcfg;
   GWEN_BUFFER *nbuf;
   uint32_t uniqueId=0;
@@ -182,19 +188,19 @@ int GWEN_ConfigMgrDir__GetUniqueId(GWEN_CONFIGMGR *cfg,
   GWEN_Buffer_AppendString(nbuf, "uniqueid");
 
   rv=GWEN_Directory_GetPath(GWEN_Buffer_GetStart(nbuf),
-			    GWEN_PATH_FLAGS_CHECKROOT |
-			    GWEN_PATH_FLAGS_VARIABLE);
+                            GWEN_PATH_FLAGS_CHECKROOT |
+                            GWEN_PATH_FLAGS_VARIABLE);
   if (rv<0) {
     DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
     return rv;
   }
 
   lck=GWEN_FSLock_new(GWEN_Buffer_GetStart(nbuf), GWEN_FSLock_TypeFile);
-  res=GWEN_FSLock_Lock(lck, 60000, guiid);
+  res=GWEN_FSLock_Lock(lck, 60000, 0);
   if (res!=GWEN_FSLock_ResultOk) {
     DBG_ERROR(GWEN_LOGDOMAIN,
-	      "Could not lock group [%s]: %d",
-	      groupName, res);
+              "Could not lock group [%s]: %d",
+              groupName, res);
     GWEN_FSLock_free(lck);
     GWEN_Buffer_free(nbuf);
     return GWEN_ERROR_LOCK;
@@ -216,8 +222,8 @@ int GWEN_ConfigMgrDir__GetUniqueId(GWEN_CONFIGMGR *cfg,
   f=fopen(GWEN_Buffer_GetStart(nbuf), "w");
   if (f==NULL) {
     DBG_ERROR(GWEN_LOGDOMAIN, "fopen(%s, \"w\"): %s",
-	      GWEN_Buffer_GetStart(nbuf),
-	      strerror(errno));
+              GWEN_Buffer_GetStart(nbuf),
+              strerror(errno));
     GWEN_FSLock_Unlock(lck);
     GWEN_FSLock_free(lck);
     GWEN_Buffer_free(nbuf);
@@ -226,8 +232,8 @@ int GWEN_ConfigMgrDir__GetUniqueId(GWEN_CONFIGMGR *cfg,
   fprintf(f, "%d", (int)uniqueId);
   if (fclose(f)) {
     DBG_ERROR(GWEN_LOGDOMAIN, "fopen(%s, \"w\"): %s",
-	      GWEN_Buffer_GetStart(nbuf),
-	      strerror(errno));
+              GWEN_Buffer_GetStart(nbuf),
+              strerror(errno));
     GWEN_FSLock_Unlock(lck);
     GWEN_FSLock_free(lck);
     GWEN_Buffer_free(nbuf);
@@ -244,9 +250,99 @@ int GWEN_ConfigMgrDir__GetUniqueId(GWEN_CONFIGMGR *cfg,
 
 
 
+int GWEN_ConfigMgrDir__UpdateLastUniqueId(GWEN_CONFIGMGR *cfg,
+                                          const char *groupName,
+                                          uint32_t uid)
+{
+  GWEN_CONFIGMGR_DIR *xcfg;
+  GWEN_BUFFER *nbuf;
+  uint32_t uniqueId=0;
+  GWEN_FSLOCK *lck;
+  GWEN_FSLOCK_RESULT res;
+  FILE *f;
+  int rv;
+
+  assert(cfg);
+  xcfg=GWEN_INHERIT_GETDATA(GWEN_CONFIGMGR, GWEN_CONFIGMGR_DIR, cfg);
+  assert(xcfg);
+
+  assert(xcfg->folder);
+  assert(groupName);
+
+  nbuf=GWEN_Buffer_new(0, 256, 0, 1);
+  GWEN_Buffer_AppendString(nbuf, xcfg->folder);
+  GWEN_Buffer_AppendString(nbuf, GWEN_DIR_SEPARATOR_S);
+  GWEN_Text_EscapeToBuffer(groupName, nbuf);
+  GWEN_Buffer_AppendString(nbuf, GWEN_DIR_SEPARATOR_S);
+  GWEN_Buffer_AppendString(nbuf, "uniqueid");
+
+  rv=GWEN_Directory_GetPath(GWEN_Buffer_GetStart(nbuf),
+                            GWEN_PATH_FLAGS_CHECKROOT |
+                            GWEN_PATH_FLAGS_VARIABLE);
+  if (rv<0) {
+    DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+    return rv;
+  }
+
+  lck=GWEN_FSLock_new(GWEN_Buffer_GetStart(nbuf), GWEN_FSLock_TypeFile);
+  res=GWEN_FSLock_Lock(lck, 60000, 0);
+  if (res!=GWEN_FSLock_ResultOk) {
+    DBG_ERROR(GWEN_LOGDOMAIN,
+              "Could not lock group [%s]: %d",
+              groupName, res);
+    GWEN_FSLock_free(lck);
+    GWEN_Buffer_free(nbuf);
+    return GWEN_ERROR_LOCK;
+  }
+
+  /* read last id */
+  f=fopen(GWEN_Buffer_GetStart(nbuf), "r");
+  if (f) {
+    int i;
+
+    if (1!=fscanf(f, "%d", &i))
+      i=0;
+    uniqueId=i;
+    fclose(f);
+  }
+
+  if (uid>uniqueId) {
+    uniqueId=uid;
+
+    f=fopen(GWEN_Buffer_GetStart(nbuf), "w");
+    if (f==NULL) {
+      DBG_ERROR(GWEN_LOGDOMAIN, "fopen(%s, \"w\"): %s",
+                GWEN_Buffer_GetStart(nbuf),
+                strerror(errno));
+      GWEN_FSLock_Unlock(lck);
+      GWEN_FSLock_free(lck);
+      GWEN_Buffer_free(nbuf);
+      return GWEN_ERROR_LOCK;
+    }
+    fprintf(f, "%d", (int)uniqueId);
+    if (fclose(f)) {
+      DBG_ERROR(GWEN_LOGDOMAIN, "fopen(%s, \"w\"): %s",
+                GWEN_Buffer_GetStart(nbuf),
+                strerror(errno));
+      GWEN_FSLock_Unlock(lck);
+      GWEN_FSLock_free(lck);
+      GWEN_Buffer_free(nbuf);
+      return GWEN_ERROR_LOCK;
+    }
+  }
+  GWEN_FSLock_Unlock(lck);
+  GWEN_FSLock_free(lck);
+  GWEN_Buffer_free(nbuf);
+
+  return 0;
+}
+
+
+
 void GWEN_ConfigMgrDir_AddGroupDirName(GWEN_CONFIGMGR *cfg,
-				       const char *groupName,
-				       GWEN_BUFFER *nbuf) {
+                                       const char *groupName,
+                                       GWEN_BUFFER *nbuf)
+{
   GWEN_CONFIGMGR_DIR *xcfg;
   uint32_t pos;
   char *p;
@@ -263,7 +359,7 @@ void GWEN_ConfigMgrDir_AddGroupDirName(GWEN_CONFIGMGR *cfg,
   pos=GWEN_Buffer_GetPos(nbuf);
   GWEN_Text_EscapeToBuffer(groupName, nbuf);
   p=GWEN_Buffer_GetStart(nbuf)+pos;
-  while(*p) {
+  while (*p) {
     *p=tolower(*p);
     p++;
   }
@@ -273,9 +369,10 @@ void GWEN_ConfigMgrDir_AddGroupDirName(GWEN_CONFIGMGR *cfg,
 
 
 void GWEN_ConfigMgrDir_AddGroupFileName(GWEN_CONFIGMGR *cfg,
-					const char *groupName,
-					const char *subGroupName,
-					GWEN_BUFFER *nbuf) {
+                                        const char *groupName,
+                                        const char *subGroupName,
+                                        GWEN_BUFFER *nbuf)
+{
   GWEN_CONFIGMGR_DIR *xcfg;
   uint32_t pos;
   char *p;
@@ -298,7 +395,7 @@ void GWEN_ConfigMgrDir_AddGroupFileName(GWEN_CONFIGMGR *cfg,
   GWEN_Buffer_AppendString(nbuf, ".conf");
 
   p=GWEN_Buffer_GetStart(nbuf)+pos;
-  while(*p) {
+  while (*p) {
     *p=tolower(*p);
     p++;
   }
@@ -306,7 +403,8 @@ void GWEN_ConfigMgrDir_AddGroupFileName(GWEN_CONFIGMGR *cfg,
 
 
 
-GWEN_FSLOCK *GWEN_ConfigMgrDir_FindLock(GWEN_CONFIGMGR *cfg, const char *fname) {
+GWEN_FSLOCK *GWEN_ConfigMgrDir_FindLock(GWEN_CONFIGMGR *cfg, const char *fname)
+{
   GWEN_CONFIGMGR_DIR *xcfg;
 
   assert(cfg);
@@ -317,7 +415,7 @@ GWEN_FSLOCK *GWEN_ConfigMgrDir_FindLock(GWEN_CONFIGMGR *cfg, const char *fname)
     GWEN_FSLOCK *lck;
 
     lck=GWEN_FSLock_List_First(xcfg->fileLocks);
-    while(lck) {
+    while (lck) {
       if (strcasecmp(GWEN_FSLock_GetName(lck), fname)==0)
         return lck;
       lck=GWEN_FSLock_List_Next(lck);
@@ -329,11 +427,11 @@ GWEN_FSLOCK *GWEN_ConfigMgrDir_FindLock(GWEN_CONFIGMGR *cfg, const char *fname)
 
 
 
-int GWEN_ConfigMgrDir_GetGroup(GWEN_CONFIGMGR *cfg,
-			       const char *groupName,
-			       const char *subGroupName,
-			       GWEN_DB_NODE **pDb,
-			       uint32_t guiid) {
+int GWENHYWFAR_CB GWEN_ConfigMgrDir_GetGroup(GWEN_CONFIGMGR *cfg,
+                                             const char *groupName,
+                                             const char *subGroupName,
+                                             GWEN_DB_NODE **pDb)
+{
   GWEN_BUFFER *nbuf;
   GWEN_CONFIGMGR_DIR *xcfg;
   int rv;
@@ -347,26 +445,24 @@ int GWEN_ConfigMgrDir_GetGroup(GWEN_CONFIGMGR *cfg,
   GWEN_ConfigMgrDir_AddGroupFileName(cfg, groupName, subGroupName, nbuf);
 
   rv=GWEN_Directory_GetPath(GWEN_Buffer_GetStart(nbuf),
-			    GWEN_PATH_FLAGS_CHECKROOT |
-			    GWEN_PATH_FLAGS_VARIABLE);
+                            GWEN_PATH_FLAGS_CHECKROOT |
+                            GWEN_PATH_FLAGS_VARIABLE);
   if (rv<0) {
     DBG_INFO(GWEN_LOGDOMAIN, "Could not access [%s]: %d",
-	     GWEN_Buffer_GetStart(nbuf), rv);
+             GWEN_Buffer_GetStart(nbuf), rv);
     GWEN_Buffer_free(nbuf);
     return rv;
   }
 
   db=GWEN_DB_Group_new(subGroupName);
   rv=GWEN_DB_ReadFile(db,
-		      GWEN_Buffer_GetStart(nbuf),
-		      GWEN_DB_FLAGS_DEFAULT |
+                      GWEN_Buffer_GetStart(nbuf),
+                      GWEN_DB_FLAGS_DEFAULT |
                       GWEN_PATH_FLAGS_CREATE_GROUP |
-		      GWEN_DB_FLAGS_ALLOW_EMPTY_STREAM,
-		      guiid,
-		      GWEN_TIMEOUT_FOREVER);
+                      GWEN_DB_FLAGS_ALLOW_EMPTY_STREAM);
   if (rv<0) {
     DBG_INFO(GWEN_LOGDOMAIN, "Could not read [%s]: %d",
-	     GWEN_Buffer_GetStart(nbuf), rv);
+             GWEN_Buffer_GetStart(nbuf), rv);
     GWEN_DB_Group_free(db);
     GWEN_Buffer_free(nbuf);
     return rv;
@@ -379,11 +475,11 @@ int GWEN_ConfigMgrDir_GetGroup(GWEN_CONFIGMGR *cfg,
 
 
 
-int GWEN_ConfigMgrDir_SetGroup(GWEN_CONFIGMGR *cfg,
-			       const char *groupName,
-			       const char *subGroupName,
-			       GWEN_DB_NODE *db,
-			       uint32_t guiid) {
+int GWENHYWFAR_CB GWEN_ConfigMgrDir_SetGroup(GWEN_CONFIGMGR *cfg,
+                                             const char *groupName,
+                                             const char *subGroupName,
+                                             GWEN_DB_NODE *db)
+{
   GWEN_BUFFER *nbuf;
   GWEN_CONFIGMGR_DIR *xcfg;
   int rv;
@@ -397,11 +493,11 @@ int GWEN_ConfigMgrDir_SetGroup(GWEN_CONFIGMGR *cfg,
   GWEN_ConfigMgrDir_AddGroupFileName(cfg, groupName, subGroupName, nbuf);
 
   rv=GWEN_Directory_GetPath(GWEN_Buffer_GetStart(nbuf),
-			    GWEN_PATH_FLAGS_CHECKROOT |
-			    GWEN_PATH_FLAGS_VARIABLE);
+                            GWEN_PATH_FLAGS_CHECKROOT |
+                            GWEN_PATH_FLAGS_VARIABLE);
   if (rv<0) {
     DBG_INFO(GWEN_LOGDOMAIN, "Could not access [%s]: %d",
-	     GWEN_Buffer_GetStart(nbuf), rv);
+             GWEN_Buffer_GetStart(nbuf), rv);
     GWEN_Buffer_free(nbuf);
     return rv;
   }
@@ -409,20 +505,18 @@ int GWEN_ConfigMgrDir_SetGroup(GWEN_CONFIGMGR *cfg,
   lck=GWEN_ConfigMgrDir_FindLock(cfg, GWEN_Buffer_GetStart(nbuf));
   if (lck==NULL) {
     DBG_ERROR(GWEN_LOGDOMAIN,
-	      "Group [%s/%s] is not locked",
-	      groupName, subGroupName);
+              "Group [%s/%s] is not locked",
+              groupName, subGroupName);
     GWEN_Buffer_free(nbuf);
     return GWEN_ERROR_LOCK;
   }
 
   rv=GWEN_DB_WriteFile(db,
-		       GWEN_Buffer_GetStart(nbuf),
-		       GWEN_DB_FLAGS_DEFAULT,
-		       guiid,
-		       GWEN_TIMEOUT_FOREVER);
+                       GWEN_Buffer_GetStart(nbuf),
+                       GWEN_DB_FLAGS_DEFAULT);
   if (rv<0) {
     DBG_INFO(GWEN_LOGDOMAIN, "Could not write [%s]: %d",
-	     GWEN_Buffer_GetStart(nbuf), rv);
+             GWEN_Buffer_GetStart(nbuf), rv);
     GWEN_Buffer_free(nbuf);
     return rv;
   }
@@ -433,10 +527,42 @@ int GWEN_ConfigMgrDir_SetGroup(GWEN_CONFIGMGR *cfg,
 
 
 
-int GWEN_ConfigMgrDir_LockGroup(GWEN_CONFIGMGR *cfg,
-				const char *groupName,
-				const char *subGroupName,
-				uint32_t guiid) {
+int GWENHYWFAR_CB GWEN_ConfigMgrDir_HasGroup(GWEN_CONFIGMGR *cfg,
+                                             const char *groupName,
+                                             const char *subGroupName)
+{
+  GWEN_BUFFER *nbuf;
+  GWEN_CONFIGMGR_DIR *xcfg;
+  int rv;
+
+  assert(cfg);
+  xcfg=GWEN_INHERIT_GETDATA(GWEN_CONFIGMGR, GWEN_CONFIGMGR_DIR, cfg);
+  assert(xcfg);
+
+  nbuf=GWEN_Buffer_new(0, 256, 0, 1);
+  GWEN_ConfigMgrDir_AddGroupFileName(cfg, groupName, subGroupName, nbuf);
+
+  rv=GWEN_Directory_GetPath(GWEN_Buffer_GetStart(nbuf),
+                            GWEN_PATH_FLAGS_CHECKROOT |
+                            GWEN_PATH_FLAGS_NAMEMUSTEXIST |
+                            GWEN_PATH_FLAGS_VARIABLE);
+  if (rv<0) {
+    DBG_INFO(GWEN_LOGDOMAIN, "Could not access [%s]: %d",
+             GWEN_Buffer_GetStart(nbuf), rv);
+    GWEN_Buffer_free(nbuf);
+    return rv;
+  }
+  GWEN_Buffer_free(nbuf);
+
+  return 0;
+}
+
+
+
+int GWENHYWFAR_CB GWEN_ConfigMgrDir_LockGroup(GWEN_CONFIGMGR *cfg,
+                                              const char *groupName,
+                                              const char *subGroupName)
+{
   GWEN_BUFFER *nbuf;
   GWEN_CONFIGMGR_DIR *xcfg;
   int rv;
@@ -451,11 +577,11 @@ int GWEN_ConfigMgrDir_LockGroup(GWEN_CONFIGMGR *cfg,
   GWEN_ConfigMgrDir_AddGroupFileName(cfg, groupName, subGroupName, nbuf);
 
   rv=GWEN_Directory_GetPath(GWEN_Buffer_GetStart(nbuf),
-			    GWEN_PATH_FLAGS_CHECKROOT |
-			    GWEN_PATH_FLAGS_VARIABLE);
+                            GWEN_PATH_FLAGS_CHECKROOT |
+                            GWEN_PATH_FLAGS_VARIABLE);
   if (rv<0) {
     DBG_INFO(GWEN_LOGDOMAIN, "Could not access [%s]: %d",
-	     GWEN_Buffer_GetStart(nbuf), rv);
+             GWEN_Buffer_GetStart(nbuf), rv);
     GWEN_Buffer_free(nbuf);
     return rv;
   }
@@ -463,33 +589,34 @@ int GWEN_ConfigMgrDir_LockGroup(GWEN_CONFIGMGR *cfg,
   lck=GWEN_ConfigMgrDir_FindLock(cfg, GWEN_Buffer_GetStart(nbuf));
   if (lck) {
     DBG_ERROR(GWEN_LOGDOMAIN,
-	      "Group [%s/%s] is already locked",
-	      groupName, subGroupName);
+              "Group [%s/%s] is already locked",
+              groupName, subGroupName);
     GWEN_Buffer_free(nbuf);
     return GWEN_ERROR_LOCK;
   }
 
   lck=GWEN_FSLock_new(GWEN_Buffer_GetStart(nbuf), GWEN_FSLock_TypeFile);
-  res=GWEN_FSLock_Lock(lck, 60000, guiid);
+  res=GWEN_FSLock_Lock(lck, 60000, 0);
   if (res!=GWEN_FSLock_ResultOk) {
     DBG_ERROR(GWEN_LOGDOMAIN,
-	      "Could not lock group [%s/%s]: %d",
-	      groupName, subGroupName, res);
+              "Could not lock group [%s/%s]: %d",
+              groupName, subGroupName, res);
     GWEN_FSLock_free(lck);
     GWEN_Buffer_free(nbuf);
     return GWEN_ERROR_LOCK;
   }
 
   GWEN_FSLock_List_Add(lck, xcfg->fileLocks);
+  GWEN_Buffer_free(nbuf);
   return 0;
 }
 
 
 
-int GWEN_ConfigMgrDir_UnlockGroup(GWEN_CONFIGMGR *cfg,
-				  const char *groupName,
-				  const char *subGroupName,
-				  GWEN_UNUSED uint32_t guiid) {
+int GWENHYWFAR_CB GWEN_ConfigMgrDir_UnlockGroup(GWEN_CONFIGMGR *cfg,
+                                                const char *groupName,
+                                                const char *subGroupName)
+{
   GWEN_BUFFER *nbuf;
   GWEN_CONFIGMGR_DIR *xcfg;
   GWEN_FSLOCK *lck;
@@ -505,8 +632,8 @@ int GWEN_ConfigMgrDir_UnlockGroup(GWEN_CONFIGMGR *cfg,
   lck=GWEN_ConfigMgrDir_FindLock(cfg, GWEN_Buffer_GetStart(nbuf));
   if (lck==NULL) {
     DBG_ERROR(GWEN_LOGDOMAIN,
-	      "Group [%s/%s] is not locked",
-	      groupName, subGroupName);
+              "Group [%s/%s] is not locked",
+              groupName, subGroupName);
     GWEN_Buffer_free(nbuf);
     return GWEN_ERROR_LOCK;
   }
@@ -514,8 +641,8 @@ int GWEN_ConfigMgrDir_UnlockGroup(GWEN_CONFIGMGR *cfg,
   res=GWEN_FSLock_Unlock(lck);
   if (res!=GWEN_FSLock_ResultOk) {
     DBG_ERROR(GWEN_LOGDOMAIN,
-	      "Could not unlock group [%s/%s]: %d",
-	      groupName, subGroupName, res);
+              "Could not unlock group [%s/%s]: %d",
+              groupName, subGroupName, res);
     GWEN_FSLock_List_Del(lck);
     GWEN_FSLock_free(lck);
     GWEN_Buffer_free(nbuf);
@@ -524,17 +651,18 @@ int GWEN_ConfigMgrDir_UnlockGroup(GWEN_CONFIGMGR *cfg,
 
   GWEN_FSLock_List_Del(lck);
   GWEN_FSLock_free(lck);
+  GWEN_Buffer_free(nbuf);
 
   return 0;
 }
 
 
 
-int GWEN_ConfigMgrDir_GetUniqueId(GWEN_CONFIGMGR *cfg,
-				  const char *groupName,
-				  char *buffer,
-				  uint32_t bufferLen,
-				  uint32_t guiid) {
+int GWENHYWFAR_CB GWEN_ConfigMgrDir_GetUniqueId(GWEN_CONFIGMGR *cfg,
+                                                const char *groupName,
+                                                char *buffer,
+                                                uint32_t bufferLen)
+{
   GWEN_CONFIGMGR_DIR *xcfg;
   int rv;
   uint32_t uid;
@@ -544,7 +672,7 @@ int GWEN_ConfigMgrDir_GetUniqueId(GWEN_CONFIGMGR *cfg,
   xcfg=GWEN_INHERIT_GETDATA(GWEN_CONFIGMGR, GWEN_CONFIGMGR_DIR, cfg);
   assert(xcfg);
 
-  rv=GWEN_ConfigMgrDir__GetUniqueId(cfg, groupName, &uid, guiid);
+  rv=GWEN_ConfigMgrDir__GetUniqueId(cfg, groupName, &uid);
   if (rv<0) {
     DBG_INFO(GWEN_LOGDOMAIN, "Could not create unique id (%d)", rv);
     return rv;
@@ -561,10 +689,72 @@ int GWEN_ConfigMgrDir_GetUniqueId(GWEN_CONFIGMGR *cfg,
 
 
 
-int GWEN_ConfigMgrDir_DeleteGroup(GWEN_CONFIGMGR *cfg,
-				  const char *groupName,
-				  const char *subGroupName,
-				  uint32_t guiid) {
+int GWENHYWFAR_CB GWEN_ConfigMgrDir_MkUniqueIdFromId(GWEN_CONFIGMGR *cfg,
+                                                     const char *groupName,
+                                                     uint32_t uid,
+                                                     int doCheck,
+                                                     char *buffer,
+                                                     uint32_t bufferLen)
+{
+  GWEN_CONFIGMGR_DIR *xcfg;
+  int rv;
+  char ubuf[64];
+
+  assert(cfg);
+  xcfg=GWEN_INHERIT_GETDATA(GWEN_CONFIGMGR, GWEN_CONFIGMGR_DIR, cfg);
+  assert(xcfg);
+
+  rv=snprintf(ubuf, sizeof(ubuf)-1, "%08x", uid);
+  if (rv>=sizeof(ubuf)-1) {
+    DBG_ERROR(GWEN_LOGDOMAIN, "Id longer than %d (%d)? SNH!", (int)(sizeof(ubuf)-1), rv);
+    return GWEN_ERROR_INTERNAL;
+  }
+  else if (rv<0) {
+    DBG_ERROR(GWEN_LOGDOMAIN, "Error on snprintf: %d", rv);
+    return GWEN_ERROR_INTERNAL;
+  }
+  ubuf[rv]=0;
+
+  if (doCheck) {
+    GWEN_BUFFER *nbuf;
+
+    /* check whether that group already exists */
+    nbuf=GWEN_Buffer_new(0, 256, 0, 1);
+    GWEN_ConfigMgrDir_AddGroupFileName(cfg, groupName, ubuf, nbuf);
+
+    rv=GWEN_Directory_GetPath(GWEN_Buffer_GetStart(nbuf),
+                              GWEN_PATH_FLAGS_CHECKROOT |
+                              GWEN_PATH_FLAGS_NAMEMUSTEXIST |
+                              GWEN_PATH_FLAGS_VARIABLE);
+    if (rv>=0) {
+      DBG_INFO(GWEN_LOGDOMAIN, "Path already exists [%s]: %d",
+               GWEN_Buffer_GetStart(nbuf), rv);
+      GWEN_Buffer_free(nbuf);
+      return rv;
+    }
+    GWEN_Buffer_free(nbuf);
+
+    /* update lastId if necessary */
+    rv=GWEN_ConfigMgrDir__UpdateLastUniqueId(cfg, groupName, uid);
+    if (rv<0) {
+      DBG_INFO(GWEN_LOGDOMAIN, "Could not update unique id (%d)", rv);
+      return rv;
+    }
+  }
+
+  /* return new id */
+  strncpy(buffer, ubuf, bufferLen-1);
+  buffer[bufferLen-1]=0;
+
+  return 0;
+}
+
+
+
+int GWENHYWFAR_CB GWEN_ConfigMgrDir_DeleteGroup(GWEN_CONFIGMGR *cfg,
+                                                const char *groupName,
+                                                const char *subGroupName)
+{
   GWEN_BUFFER *nbuf;
   GWEN_CONFIGMGR_DIR *xcfg;
   int rv;
@@ -579,11 +769,11 @@ int GWEN_ConfigMgrDir_DeleteGroup(GWEN_CONFIGMGR *cfg,
   GWEN_ConfigMgrDir_AddGroupFileName(cfg, groupName, subGroupName, nbuf);
 
   rv=GWEN_Directory_GetPath(GWEN_Buffer_GetStart(nbuf),
-			    GWEN_PATH_FLAGS_CHECKROOT |
-			    GWEN_PATH_FLAGS_VARIABLE);
+                            GWEN_PATH_FLAGS_CHECKROOT |
+                            GWEN_PATH_FLAGS_VARIABLE);
   if (rv<0) {
     DBG_INFO(GWEN_LOGDOMAIN, "Could not access [%s]: %d",
-	     GWEN_Buffer_GetStart(nbuf), rv);
+             GWEN_Buffer_GetStart(nbuf), rv);
     GWEN_Buffer_free(nbuf);
     return rv;
   }
@@ -591,18 +781,18 @@ int GWEN_ConfigMgrDir_DeleteGroup(GWEN_CONFIGMGR *cfg,
   lck=GWEN_ConfigMgrDir_FindLock(cfg, GWEN_Buffer_GetStart(nbuf));
   if (lck) {
     DBG_ERROR(GWEN_LOGDOMAIN,
-	      "Group [%s/%s] is still locked",
-	      groupName, subGroupName);
+              "Group [%s/%s] is still locked",
+              groupName, subGroupName);
     GWEN_Buffer_free(nbuf);
     return GWEN_ERROR_LOCK;
   }
 
   lck=GWEN_FSLock_new(GWEN_Buffer_GetStart(nbuf), GWEN_FSLock_TypeFile);
-  res=GWEN_FSLock_Lock(lck, 60000, guiid);
+  res=GWEN_FSLock_Lock(lck, 60000, 0);
   if (res!=GWEN_FSLock_ResultOk) {
     DBG_ERROR(GWEN_LOGDOMAIN,
-	      "Could not lock group [%s/%s]: %d",
-	      groupName, subGroupName, res);
+              "Could not lock group [%s/%s]: %d",
+              groupName, subGroupName, res);
     GWEN_FSLock_free(lck);
     GWEN_Buffer_free(nbuf);
     return GWEN_ERROR_LOCK;
@@ -619,9 +809,9 @@ int GWEN_ConfigMgrDir_DeleteGroup(GWEN_CONFIGMGR *cfg,
 
 
 
-int GWEN_ConfigMgrDir_ListGroups(GWEN_CONFIGMGR *cfg,
-				 GWEN_STRINGLIST *sl,
-				 GWEN_UNUSED uint32_t guiid) {
+int GWENHYWFAR_CB GWEN_ConfigMgrDir_ListGroups(GWEN_CONFIGMGR *cfg,
+                                               GWEN_STRINGLIST *sl)
+{
   GWEN_CONFIGMGR_DIR *xcfg;
   int rv;
 
@@ -642,10 +832,10 @@ int GWEN_ConfigMgrDir_ListGroups(GWEN_CONFIGMGR *cfg,
 
 
 
-int GWEN_ConfigMgrDir_ListSubGroups(GWEN_CONFIGMGR *cfg,
-				    const char *groupName,
-				    GWEN_STRINGLIST *sl,
-				    GWEN_UNUSED uint32_t guiid) {
+int GWENHYWFAR_CB GWEN_ConfigMgrDir_ListSubGroups(GWEN_CONFIGMGR *cfg,
+                                                  const char *groupName,
+                                                  GWEN_STRINGLIST *sl)
+{
   GWEN_BUFFER *nbuf;
   GWEN_CONFIGMGR_DIR *xcfg;
   int rv;
@@ -659,9 +849,9 @@ int GWEN_ConfigMgrDir_ListSubGroups(GWEN_CONFIGMGR *cfg,
   GWEN_ConfigMgrDir_AddGroupDirName(cfg, groupName, nbuf);
 
   rv=GWEN_Directory_GetPath(GWEN_Buffer_GetStart(nbuf),
-			    GWEN_PATH_FLAGS_CHECKROOT |
+                            GWEN_PATH_FLAGS_CHECKROOT |
                             GWEN_PATH_FLAGS_PATHMUSTEXIST |
-			    GWEN_PATH_FLAGS_NAMEMUSTEXIST);
+                            GWEN_PATH_FLAGS_NAMEMUSTEXIST);
   if (rv<0) {
     DBG_INFO(GWEN_LOGDOMAIN, "Path not found (%d)", rv);
     GWEN_Buffer_free(nbuf);
@@ -682,7 +872,7 @@ int GWEN_ConfigMgrDir_ListSubGroups(GWEN_CONFIGMGR *cfg,
 
     tbuf=GWEN_Buffer_new(0, 256, 0, 1);
     se=GWEN_StringList_FirstEntry(rawsl);
-    while(se) {
+    while (se) {
       char buffer[256];
       char *p;
 
@@ -690,9 +880,9 @@ int GWEN_ConfigMgrDir_ListSubGroups(GWEN_CONFIGMGR *cfg,
       buffer[sizeof(buffer)-1]=0;
       p=strrchr(buffer, '.');
       if (p) {
-	*p=0;
-	GWEN_Text_UnescapeToBuffer(buffer, tbuf);
-	GWEN_StringList_AppendString(sl, GWEN_Buffer_GetStart(tbuf), 0, 1);
+        *p=0;
+        GWEN_Text_UnescapeToBuffer(buffer, tbuf);
+        GWEN_StringList_AppendString(sl, GWEN_Buffer_GetStart(tbuf), 0, 1);
         GWEN_Buffer_Reset(tbuf);
       }
 
