@@ -73,7 +73,7 @@ void GWEN_PluginDescription_free(GWEN_PLUGIN_DESCRIPTION *pd);
 
 
 GWENHYWFAR_API
-GWEN_PLUGIN_DESCRIPTION*
+GWEN_PLUGIN_DESCRIPTION *
 GWEN_PluginDescription_dup(const GWEN_PLUGIN_DESCRIPTION *pd);
 
 GWENHYWFAR_API
@@ -89,8 +89,8 @@ void GWEN_PluginDescription_Attach(GWEN_PLUGIN_DESCRIPTION *pd);
  * you want the XML node to survive the description.
  */
 GWENHYWFAR_API
-GWEN_XMLNODE*
-  GWEN_PluginDescription_GetXmlNode(const GWEN_PLUGIN_DESCRIPTION *pd);
+GWEN_XMLNODE *
+GWEN_PluginDescription_GetXmlNode(const GWEN_PLUGIN_DESCRIPTION *pd);
 
 GWENHYWFAR_API
 const char *GWEN_PluginDescription_GetPath(const GWEN_PLUGIN_DESCRIPTION *pd);
@@ -106,24 +106,24 @@ GWENHYWFAR_API
 const char *GWEN_PluginDescription_GetType(const GWEN_PLUGIN_DESCRIPTION *pd);
 
 GWENHYWFAR_API
-const char*
-  GWEN_PluginDescription_GetShortDescr(const GWEN_PLUGIN_DESCRIPTION *pd);
+const char *
+GWEN_PluginDescription_GetShortDescr(const GWEN_PLUGIN_DESCRIPTION *pd);
 
 GWENHYWFAR_API
-const char*
-  GWEN_PluginDescription_GetAuthor(const GWEN_PLUGIN_DESCRIPTION *pd);
+const char *
+GWEN_PluginDescription_GetAuthor(const GWEN_PLUGIN_DESCRIPTION *pd);
 
 GWENHYWFAR_API
-const char*
-  GWEN_PluginDescription_GetVersion(const GWEN_PLUGIN_DESCRIPTION *pd);
+const char *
+GWEN_PluginDescription_GetVersion(const GWEN_PLUGIN_DESCRIPTION *pd);
 
 GWENHYWFAR_API
-const char*
-  GWEN_PluginDescription_GetLongDescr(const GWEN_PLUGIN_DESCRIPTION *pd);
+const char *
+GWEN_PluginDescription_GetLongDescr(const GWEN_PLUGIN_DESCRIPTION *pd);
 
 GWENHYWFAR_API
-const char*
-  GWEN_PluginDescription_GetFileName(const GWEN_PLUGIN_DESCRIPTION *pd);
+const char *
+GWEN_PluginDescription_GetFileName(const GWEN_PLUGIN_DESCRIPTION *pd);
 
 GWENHYWFAR_API
 void GWEN_PluginDescription_SetFileName(GWEN_PLUGIN_DESCRIPTION *pd,
@@ -131,6 +131,7 @@ void GWEN_PluginDescription_SetFileName(GWEN_PLUGIN_DESCRIPTION *pd,
 
 
 
+#ifndef NO_DEPRECATED_SYMBOLS
 /**
  * <p>
  * Seeks for a long description with the given format and the currently
@@ -149,17 +150,18 @@ void GWEN_PluginDescription_SetFileName(GWEN_PLUGIN_DESCRIPTION *pd,
  * @param s name of the format (e.g. <i>html</i>)
  * @param buf buffer to append the description to
  */
-GWENHYWFAR_API
+GWENHYWFAR_API GWEN_DEPRECATED
 int
 GWEN_PluginDescription_GetLongDescrByFormat(const GWEN_PLUGIN_DESCRIPTION *pd,
                                             const char *s,
                                             GWEN_BUFFER *buf);
+#endif  // ifndef NO_DEPRECATED_SYMBOLS
 
 GWENHYWFAR_API
-  int GWEN_PluginDescription_IsActive(const GWEN_PLUGIN_DESCRIPTION *pd);
+int GWEN_PluginDescription_IsActive(const GWEN_PLUGIN_DESCRIPTION *pd);
 
 GWENHYWFAR_API
-  void GWEN_PluginDescription_SetIsActive(GWEN_PLUGIN_DESCRIPTION *pd, int i);
+void GWEN_PluginDescription_SetIsActive(GWEN_PLUGIN_DESCRIPTION *pd, int i);
 
 
 #ifdef __cplusplus
