@@ -29,7 +29,8 @@
 GWEN_LIST_FUNCTIONS(GWEN_TAG16, GWEN_Tag16)
 
 
-GWEN_TAG16 *GWEN_Tag16_new() {
+GWEN_TAG16 *GWEN_Tag16_new(void)
+{
   GWEN_TAG16 *tlv;
 
   GWEN_NEW_OBJECT(GWEN_TAG16, tlv);
@@ -40,7 +41,8 @@ GWEN_TAG16 *GWEN_Tag16_new() {
 
 
 
-void GWEN_Tag16_free(GWEN_TAG16 *tlv) {
+void GWEN_Tag16_free(GWEN_TAG16 *tlv)
+{
   if (tlv) {
     if (tlv->dataOwned)
       free(tlv->tagData);
@@ -51,37 +53,41 @@ void GWEN_Tag16_free(GWEN_TAG16 *tlv) {
 
 
 
-unsigned int GWEN_Tag16_GetTagType(const GWEN_TAG16 *tlv){
+unsigned int GWEN_Tag16_GetTagType(const GWEN_TAG16 *tlv)
+{
   assert(tlv);
   return tlv->tagType;
 }
 
 
 
-unsigned int GWEN_Tag16_GetTagLength(const GWEN_TAG16 *tlv){
+unsigned int GWEN_Tag16_GetTagLength(const GWEN_TAG16 *tlv)
+{
   assert(tlv);
   return tlv->tagLength;
 }
 
 
 
-unsigned int GWEN_Tag16_GetTagSize(const GWEN_TAG16 *tlv){
+unsigned int GWEN_Tag16_GetTagSize(const GWEN_TAG16 *tlv)
+{
   assert(tlv);
   return tlv->tagSize;
 }
 
 
 
-const void *GWEN_Tag16_GetTagData(const GWEN_TAG16 *tlv){
+const void *GWEN_Tag16_GetTagData(const GWEN_TAG16 *tlv)
+{
   assert(tlv);
   return tlv->tagData;
 }
 
 
 
-GWEN_TAG16 *GWEN_Tag16_fromBuffer(GWEN_BUFFER *mbuf, int isBerTlv) {
+GWEN_TAG16 *GWEN_Tag16_fromBuffer(GWEN_BUFFER *mbuf, GWEN_UNUSED int isBerTlv)
+{
   const char *p;
-  unsigned int tagMode;
   unsigned int tagType;
   unsigned int tagLength;
   const char *tagData;
@@ -98,7 +104,7 @@ GWEN_TAG16 *GWEN_Tag16_fromBuffer(GWEN_BUFFER *mbuf, int isBerTlv) {
 
   startPos=GWEN_Buffer_GetPos(mbuf);
 
-  tagMode=tagType=tagLength=0;
+  tagType=tagLength=0;
 
   p=GWEN_Buffer_GetPosPointer(mbuf);
   pos=0;
@@ -130,7 +136,7 @@ GWEN_TAG16 *GWEN_Tag16_fromBuffer(GWEN_BUFFER *mbuf, int isBerTlv) {
   tlv->tagType=tagType;
   tlv->tagLength=tagLength;
   if (tagLength) {
-    tlv->tagData=(void*)malloc(tagLength);
+    tlv->tagData=(void *)malloc(tagLength);
     memmove(tlv->tagData, tagData, tagLength);
     tlv->dataOwned=1;
   }
@@ -142,7 +148,8 @@ GWEN_TAG16 *GWEN_Tag16_fromBuffer(GWEN_BUFFER *mbuf, int isBerTlv) {
 
 
 
-GWEN_TAG16 *GWEN_Tag16_fromBuffer2(const uint8_t *p, uint32_t l, int doCopy) {
+GWEN_TAG16 *GWEN_Tag16_fromBuffer2(const uint8_t *p, uint32_t l, int doCopy)
+{
   unsigned int tagType;
   unsigned int tagLength;
   const uint8_t *tagData;
@@ -187,12 +194,12 @@ GWEN_TAG16 *GWEN_Tag16_fromBuffer2(const uint8_t *p, uint32_t l, int doCopy) {
   tlv->tagLength=tagLength;
   if (tagLength) {
     if (doCopy) {
-      tlv->tagData=(void*)malloc(tagLength);
+      tlv->tagData=(void *)malloc(tagLength);
       memmove(tlv->tagData, tagData, tagLength);
       tlv->dataOwned=1;
     }
     else {
-      tlv->tagData=(uint8_t*)tagData;
+      tlv->tagData=(uint8_t *)tagData;
       tlv->dataOwned=0;
     }
   }
@@ -206,7 +213,8 @@ GWEN_TAG16 *GWEN_Tag16_fromBuffer2(const uint8_t *p, uint32_t l, int doCopy) {
 void GWEN_Tag16_DirectlyToBuffer(unsigned int tagType,
                                  const char *p,
                                  int size,
-                                 GWEN_BUFFER *buf){
+                                 GWEN_BUFFER *buf)
+{
   assert(buf);
   if (size==-1) {
     assert(p);
