@@ -31,9 +31,7 @@
 #include <gwenhywfar/debug.h>
 #include <gwenhywfar/logger.h>
 #include <gwenhywfar/xml.h>
-#include <gwenhywfar/io_file.h>
-#include <gwenhywfar/io_buffered.h>
-#include <gwenhywfar/iomanager.h>
+#include <gwenhywfar/syncio_file.h>
 
 #include <stdlib.h>
 #include <assert.h>
@@ -46,35 +44,36 @@
 
 
 int addDefinitions(GWEN_XMLNODE *top,
-                   GWEN_XMLNODE *node) {
+                   GWEN_XMLNODE *node)
+{
   GWEN_XMLNODE *nsrc, *ndst;
 
   assert(top);
   assert(node);
 
   nsrc=GWEN_XMLNode_GetChild(node);
-  while(nsrc) {
+  while (nsrc) {
     if (GWEN_XMLNode_GetType(nsrc)==GWEN_XMLNodeTypeTag) {
       ndst=GWEN_XMLNode_FindNode(top, GWEN_XMLNodeTypeTag,
                                  GWEN_XMLNode_GetData(nsrc));
       if (ndst) {
-	GWEN_XMLNODE *n;
+        GWEN_XMLNODE *n;
 
         n=GWEN_XMLNode_GetChild(nsrc);
-	while (n) {
-	  GWEN_XMLNODE *newNode;
+        while (n) {
+          GWEN_XMLNODE *newNode;
 
           DBG_DEBUG(0, "Adding node \"%s\"", GWEN_XMLNode_GetData(n));
           newNode=GWEN_XMLNode_dup(n);
           GWEN_XMLNode_AddChild(ndst, newNode);
-	  n=GWEN_XMLNode_Next(n);
-	} /* while n */
+          n=GWEN_XMLNode_Next(n);
+        } /* while n */
       }
       else {
-	GWEN_XMLNODE *newNode;
+        GWEN_XMLNODE *newNode;
 
         DBG_DEBUG(0, "Adding branch \"%s\"", GWEN_XMLNode_GetData(nsrc));
-	newNode=GWEN_XMLNode_dup(nsrc);
+        newNode=GWEN_XMLNode_dup(nsrc);
         GWEN_XMLNode_AddChild(top, newNode);
       }
     } /* if TAG */
@@ -86,15 +85,15 @@ int addDefinitions(GWEN_XMLNODE *top,
 
 
 
-int main(int argc, char **argv) {
+int main(int argc, char **argv)
+{
   ARGUMENTS *args;
   int rv;
   FREEPARAM *inFile;
   GWEN_XMLNODE *top;
   GWEN_XMLNODE *comment;
-  GWEN_IO_LAYER *io;
+  GWEN_SYNCIO *sio;
   GWEN_XML_CONTEXT *ctx;
-  int fd;
   uint32_t flags;
 
   rv=GWEN_Init();
@@ -145,7 +144,7 @@ int main(int argc, char **argv) {
   }
 
   /* read all files */
-  while(inFile) {
+  while (inFile) {
     GWEN_XMLNODE *n;
 
     n=GWEN_XMLNode_new(GWEN_XMLNodeTypeTag, "inFile");
@@ -169,20 +168,6 @@ int main(int argc, char **argv) {
   } /* while */
 
   /* write file */
-  if (args->outputFile) {
-    fd=open(args->outputFile, O_RDWR | O_CREAT | O_TRUNC, S_IRUSR | S_IWUSR);
-    if (fd==-1) {
-      fprintf(stderr, "Error opening file \"%s\": %s\n",
-              args->outputFile,
-              strerror(errno));
-      GWEN_XMLNode_free(top);
-      return 4;
-    }
-  }
-  else {
-    fd=1;
-  }
-
   if (args->compact) {
     flags=GWEN_XML_FLAGS_SIMPLE;
   }
@@ -191,32 +176,50 @@ int main(int argc, char **argv) {
   }
   flags|=GWEN_XML_FLAGS_HANDLE_HEADERS;
 
-  ctx=GWEN_XmlCtxStore_new(NULL, flags, 0, 10000);
+  ctx=GWEN_XmlCtxStore_new(NULL, flags);
 
-  io=GWEN_Io_LayerFile_new(-1, fd);
-  GWEN_Io_Manager_RegisterLayer(io);
-
-  rv=GWEN_XMLNode_WriteToStream(top, ctx, io);
+  sio=GWEN_SyncIo_File_new(args->outputFile, GWEN_SyncIo_File_CreationMode_CreateAlways);
+  GWEN_SyncIo_AddFlags(sio,
+                       GWEN_SYNCIO_FILE_FLAGS_READ |
+                       GWEN_SYNCIO_FILE_FLAGS_WRITE |
+                       GWEN_SYNCIO_FILE_FLAGS_UREAD |
+                       GWEN_SYNCIO_FILE_FLAGS_UWRITE |
+                       GWEN_SYNCIO_FILE_FLAGS_GREAD |
+                       GWEN_SYNCIO_FILE_FLAGS_GWRITE);
+  rv=GWEN_SyncIo_Connect(sio);
   if (rv<0) {
-    DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
-    GWEN_Io_Layer_Disconnect(io, GWEN_IO_REQUEST_FLAGS_FORCE, 0, 1000);
-    GWEN_Io_Layer_free(io);
+    fprintf(stderr, "Error opening file \"%s\": %s\n",
+            args->outputFile,
+            strerror(errno));
+    GWEN_SyncIo_Disconnect(sio);
+    GWEN_SyncIo_free(sio);
+    GWEN_XmlCtx_free(ctx);
+    return 5;
+  }
+
+
+  rv=GWEN_XMLNode_WriteToStream(top, ctx, sio);
+  if (rv<0) {
+    fprintf(stderr, "Error writing to file \"%s\": %s\n",
+            args->outputFile,
+            strerror(errno));
+    GWEN_SyncIo_Disconnect(sio);
+    GWEN_SyncIo_free(sio);
     GWEN_XmlCtx_free(ctx);
     return 5;
   }
 
   /* close file */
-  rv=GWEN_Io_Layer_DisconnectRecursively(io, NULL, 0, GWEN_XmlCtx_GetGuiId(ctx), 30000);
+  rv=GWEN_SyncIo_Disconnect(sio);
   if (rv<0) {
     fprintf(stderr, "Error closing output stream (%d)\n", rv);
     DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
-    GWEN_Io_Layer_Disconnect(io, GWEN_IO_REQUEST_FLAGS_FORCE, GWEN_XmlCtx_GetGuiId(ctx), 1000);
-    GWEN_Io_Layer_free(io);
+    GWEN_SyncIo_free(sio);
     GWEN_XmlCtx_free(ctx);
     return 5;
   }
 
-  GWEN_Io_Layer_free(io);
+  GWEN_SyncIo_free(sio);
   GWEN_XmlCtx_free(ctx);
 
   GWEN_XMLNode_free(top);
